const test = require('tape')
const crypto = require('crypto')

const { connect } = require('scuttle-testbot')
const Server = require('./testbot')

test('hyperBlobs.registerDrive', t => {
  let plan = 2
  const caps = {
    shs: crypto.randomBytes(32).toString('base64')
  }
  const alice = Server({
    caps,
    hyperBlobs: {
      port: 61001
    }
  })
  const bob = Server({
    caps,
    hyperBlobs: {
      port: 61002
    }
  })

  alice.hyperBlobs.registerDrive.hook(function (registerDrive, args) {
    bob.hyperBlobs.driveAddress((_, bobDrive) => {
      t.equal(args[0], bobDrive, 'bob remotely calls alice to register his driveAddress')
      registerDrive.apply(this, args)

      next()
    })
  })

  bob.hyperBlobs.registerDrive.hook(function (registerDrive, args) {
    alice.hyperBlobs.driveAddress((_, aliceDrive) => {
      t.equal(args[0], aliceDrive, 'alice remotely calls bob to register his driveAddress')
      registerDrive.apply(this, args)

      next()
    })
  })

  connect([alice, bob], {}, (err) => {
    if (err) throw err
  })

  function next () {
    plan--
    if (plan === 0) {
      alice.close()
      bob.close()
      t.end()
    }
  }
})
